@@ -5,9 +5,9 @@ use strict 'subs', 'vars';
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-12-04'; # DATE
+our $DATE = '2023-12-05'; # DATE
 our $DIST = 'App-GraphicsColorNamesUtils'; # DIST
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 our %SPEC;
 
@@ -83,7 +83,7 @@ sub colorcode2name {
             }
             map {
                 # name, code, distance to wanted
-                [$_, $all_codes->{$_}, Color::RGB::Util::rgb_diff($code, $all_codes->{$_}, 'approx1')]
+                [$_, $all_codes->{$_}, do { Color::RGB::Util::rgb_diff($code, sprintf("%06x",$all_codes->{$_}), 'approx1')}]
             } sort keys %$all_codes;
         my @closest = splice @colors_and_diffs, 0, 5;
         return [200, "OK (approx)", [map {+{name=>$_->[0], code=>$_->[1]}} @closest], {
@@ -261,7 +261,7 @@ App::GraphicsColorNamesUtils - Utilities related to Graphics::ColorNames
 
 =head1 VERSION
 
-This document describes version 0.007 of App::GraphicsColorNamesUtils (from Perl distribution App-GraphicsColorNamesUtils), released on 2023-12-04.
+This document describes version 0.008 of App::GraphicsColorNamesUtils (from Perl distribution App-GraphicsColorNamesUtils), released on 2023-12-05.
 
 =head1 DESCRIPTION
 
